@@ -32,30 +32,36 @@ OC.L10N.register(
     "Edit" : "تعديل",
     "Delete" : "حذف ",
     "Untitled calendar" : "تقويم بدون اسم",
-    "Edit name" : "تعديل الاسم",
-    "Saving name …" : "جاري حفظ الاسم   …",
-    "Edit color" : "تعديل اللون",
-    "Saving color …" : "جاري حفظ اللون    …",
-    "Copy private link" : "نسخ الرابط الخاص",
-    "Export" : "تصدير",
-    "Unshare from me" : "أنت ألغيت المشاركة",
+    "Shared with you by" : "مشاركة معك من قبل",
     "An error occurred, unable to change visibility of the calendar." : "حدث خطأ، لا يمكن تعديل وضعية ظهور التقويم.",
-    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
-    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم.",
-    "Calendar link could not be copied to clipboard." : "لم نتمكن من نسخ رابط التقويم.",
-    "An error occurred, unable to rename the calendar." : "حدث خطأ، لا يمكن تعديل اسم التقويم.",
-    "An error occurred, unable to change the calendar's color." : "حدث خطأ، لا يمكن تعديل لون التقويم.",
-    "Share link" : "رابط المشاركة",
-    "Publish calendar" : "نشر التقويم",
-    "Publishing calendar" : "جاري نشر التقويم",
-    "Copy public link" : "نسخ الرابط العام",
-    "Send link to calendar via email" : "ارسال رابط التقويم عبر البريد",
-    "Enter one address" : "ادخل عنوان بريدي واحد",
-    "Sending email …" : "جاري ارسال البريد  …",
+    "New calendar" : "تقويم جديد",
+    "Creating calendar …" : "جاري انشاء تقويم  …",
+    "New calendar with task list" : "تقويم جديد مع قائمة مهام",
+    "New subscription from link (read-only)" : "مشتركين جدد عن طريق رابط (للقراءة فقط)",
+    "Creating subscription …" : "جاري انشاء اشتراك  …",
+    "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
     "Copy subscription link" : "نسخ رابط الاشتراك",
     "Copying link …" : "جاري نسخ رابط  …",
     "Copied link" : "تم نسخ الرابط",
     "Could not copy link" : "لا يمكن نسخ الرابط",
+    "Export" : "تصدير",
+    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم.",
+    "Calendar link could not be copied to clipboard." : "لم نتمكن من نسخ رابط التقويم.",
+    "Trash bin" : "المهملات",
+    "Name" : "الاسم",
+    "Deleted" : "تم حذفه",
+    "Restore" : "استعادة ",
+    "Delete permanently" : "حذف بشكل دائم",
+    "Empty trash bin" : "تفريغ سلة المهملات",
+    "Untitled item" : "بند غير معنون",
+    "Unknown calendar" : "تقويم غير معروف",
+    "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
+    "Share link" : "رابط المشاركة",
+    "Copy public link" : "نسخ الرابط العام",
+    "Send link to calendar via email" : "ارسال رابط التقويم عبر البريد",
+    "Enter one address" : "ادخل عنوان بريدي واحد",
+    "Sending email …" : "جاري ارسال البريد  …",
     "Copy embedding code" : "نسخ الكود المرفق",
     "Copying code …" : "نسخ الكود  …",
     "Copied code" : "تم نسخ الكود",
@@ -67,28 +73,14 @@ OC.L10N.register(
     "Embed code copied to clipboard." : "تم نسخ الكود المرفق.",
     "Embed code could not be copied to clipboard." : "لا يمكن نسخ الكود المرفق",
     "Unpublishing calendar failed" : "فشل في الغاء نشر التقويم",
-    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
-    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
     "can edit" : "يمكن التحرير",
     "Unshare with {displayName}" : "الغاء المشاركة مع {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "حدث خطأ، لا يمكن تعديل نشر التقويم",
     "An error occurred, unable to change the permission of the share." : "حدث خطأ، لا يمكن تعديل صلاحيات نشر التقويم.",
-    "+ New calendar" : "+ تقويم جديد",
-    "New calendar" : "تقويم جديد",
-    "Creating calendar …" : "جاري انشاء تقويم  …",
-    "New calendar with task list" : "تقويم جديد مع قائمة مهام",
-    "New subscription from link (read-only)" : "مشتركين جدد عن طريق رابط (للقراءة فقط)",
-    "Creating subscription …" : "جاري انشاء اشتراك  …",
-    "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
-    "Trash bin" : "المهملات",
-    "Name" : "الاسم",
-    "Deleted" : "تم حذفه",
-    "Restore" : "استعادة ",
-    "Delete permanently" : "حذف بشكل دائم",
-    "Empty trash bin" : "تفريغ سلة المهملات",
-    "Unknown calendar" : "تقويم غير معروف",
-    "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
+    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
+    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
+    "Copy private link" : "نسخ الرابط الخاص",
+    "Unshare from me" : "أنت ألغيت المشاركة",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
     "Filename" : "اسم الملف",
@@ -301,6 +293,7 @@ OC.L10N.register(
     "Custom color" : "لون خاص",
     "Special color of this event. Overrides the calendar-color." : "اللون الخاص للفعالية هذه، يعيد تعيين لون التقويم.",
     "Chat room for event" : "غرفة محادثة للفعالية",
+    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
     "Imported {filename}" : "استيراد {filename}",
     "Meditation" : "تفكير",
     "Relaxing" : "لحظة راحة",
