@@ -26,30 +26,32 @@ OC.L10N.register(
     "Edit" : "Sunting",
     "Delete" : "Hapus",
     "Untitled calendar" : "Kalender tanpa judul",
-    "Edit name" : "Edit nama",
-    "Saving name …" : "Menyimpan nama …",
-    "Edit color" : "Edit warna",
-    "Saving color …" : "Menyimpan warna …",
-    "Copy private link" : "Salin tautan privat",
-    "Export" : "Ekspor",
     "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
-    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
-    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
-    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
-    "An error occurred, unable to rename the calendar." : "Terjadi galat, tidak dapat mengubah nama kalender.",
-    "An error occurred, unable to change the calendar's color." : "Terjadi galat, tidak dapat mengganti warna kalender.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
-    "Share link" : "Bagikan tautan",
-    "Publish calendar" : "Menerbitkan kalender",
-    "Publishing calendar" : "Menerbitkan kalender",
-    "Copy public link" : "Salin tautan publik",
-    "Send link to calendar via email" : "Kirim tautan kalender via surel",
-    "Sending email …" : "Mengirim surel …",
+    "New calendar" : "Kalender baru",
+    "Creating calendar …" : "Membuat kalender …",
+    "New calendar with task list" : "Kalender baru dengan daftar tugas",
+    "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
+    "Creating subscription …" : "Membuat langganan …",
+    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
     "Copy subscription link" : "Salin tautan berlangganan",
     "Copying link …" : "Menyalin tautan …",
     "Copied link" : "Tautan tersalin",
     "Could not copy link" : "Tidak dapat menyalin tautan",
+    "Export" : "Ekspor",
+    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
+    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
+    "Name" : "Nama",
+    "Deleted" : "Dihapus",
+    "Restore" : "Pulihkan",
+    "Delete permanently" : "Hapus secara permanen",
+    "Empty trash bin" : "Kosongkan tempat sampah",
+    "Share link" : "Bagikan tautan",
+    "Copy public link" : "Salin tautan publik",
+    "Send link to calendar via email" : "Kirim tautan kalender via surel",
+    "Sending email …" : "Mengirim surel …",
     "Copy embedding code" : "Salin kode penyemat",
     "Copying code …" : "Menyalin kode …",
     "Copied code" : "Kode tersalin",
@@ -61,24 +63,13 @@ OC.L10N.register(
     "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
     "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
     "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
-    "Share with users or groups" : "Berbagi dengan pengguna atau grup",
-    "No users or groups" : "Tidak ada pengguna atau grup",
     "can edit" : "dapat edit",
     "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
     "An error occurred, unable to change the unshare the calendar." : "Terjadi galat, tidak dapat mengubah pembatalan berbagi kalender.",
     "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
-    "New calendar" : "Kalender baru",
-    "Creating calendar …" : "Membuat kalender …",
-    "New calendar with task list" : "Kalender baru dengan daftar tugas",
-    "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
-    "Creating subscription …" : "Membuat langganan …",
-    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
-    "Name" : "Nama",
-    "Deleted" : "Dihapus",
-    "Restore" : "Pulihkan",
-    "Delete permanently" : "Hapus secara permanen",
-    "Empty trash bin" : "Kosongkan tempat sampah",
+    "Share with users or groups" : "Berbagi dengan pengguna atau grup",
+    "No users or groups" : "Tidak ada pengguna atau grup",
+    "Copy private link" : "Salin tautan privat",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
@@ -260,6 +251,7 @@ OC.L10N.register(
     "Custom color" : "Warna khusus",
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "Chat room for event" : "Ruang obrolan untuk acara",
+    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "Talk" : "Talk",
     "Review" : "Tinjauan",
     "Mail" : "Email",
