@@ -16,15 +16,11 @@ OC.L10N.register(
     "Schedule an appointment" : "Planifică o programare",
     "Prepare for %s" : "Pregăteste-te de %s",
     "Follow up for %s" : "Urmărește-ne pentru %s",
-    "Your appointment \"%s\" needs confirmation" : "Programarea \"%s\" necesită confirmare",
     "Dear %s, please confirm your booking" : "Dragă %s, te rog să confirmi rezervarea ta",
     "Confirm" : "Confirmă",
     "This confirmation link expires in %s hours." : "Acest link de confirmare expira în %s ore. ",
-    "If you wish to cancel the appointment after all, please contact your organizer." : "Dacă dorești să anulezi programarea, te rugăm să contactezi organizatorul.",
-    "Appointment:" : "Programare:",
     "Date:" : "Data:",
     "Where:" : "Unde:",
-    "Description:" : "Descriere:",
     "Calendar" : "Calendar",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
@@ -47,49 +43,9 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
     "Add new" : "Adaugă nou",
     "Untitled calendar" : "Calendar nedenumit",
-    "Edit name" : "Modifică numele",
-    "Saving name …" : "Se salvează numele ...",
-    "Edit color" : "Modifică culoarea",
-    "Saving color …" : "Se salvează culoarea  ...",
-    "Copy private link" : "Copiază link privat",
-    "Export" : "Exportă",
-    "Unshare from me" : "Anulare partajarea cu mine",
     "An error occurred, unable to change visibility of the calendar." : "A apărut o eroare, nu se poate schimba vizibilitatea calendarului.",
-    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
-    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
-    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
-    "An error occurred, unable to rename the calendar." : "A apărut o eroare, acest calendar nu se poate redenumi.",
-    "An error occurred, unable to change the calendar's color." : "A apărut o eroare, nu se poate schimba culoarea calendarului.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Oprirea partajării calendarului in {countdown} secundă","Oprirea partajării calendarului în {countdown} secunde","Oprirea partajării calendarului în {countdown} de secunde"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Se șterge calendarul în {countdown} secundă","Se șterge calendarul în {countdown} secunde","Se șterge calendarul în {countdown} de secunde"],
-    "Share link" : "Partajază legătură",
-    "Publish calendar" : "Publică calendarul",
-    "Publishing calendar" : "Se publică calendarul",
-    "Copy public link" : "Copiză link-ul public",
-    "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
-    "Enter one address" : "Introdu o adresă",
-    "Sending email …" : "Email-ul se trimite ...",
-    "Copy subscription link" : "Copiază linkul abonamentului",
-    "Copying link …" : "Copiază link ...",
-    "Copied link" : "Link copiat",
-    "Could not copy link" : "Nu s-a putut copia link-ul",
-    "Copy embedding code" : "Copiați codul de încorporare",
-    "Copying code …" : "Se copiază codul ...",
-    "Copied code" : "Codul a fost copiat",
-    "Could not copy code" : "Nu sa putut copia codul",
-    "Delete share link" : "Șterge linkul partajat",
-    "Deleting share link …" : "Se şterge linkul de partajare ...",
-    "An error occurred, unable to publish calendar." : "A apărut o eroare, nu se poate publica calendarul.",
-    "An error occurred, unable to send email." : "A apărut o eroare, nu se poate trimite email-ul.",
-    "Embed code copied to clipboard." : "Codul a fost copiat în clipboard.",
-    "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
-    "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
-    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
-    "No users or groups" : "Nu sunt utilizatori sau grupuri",
-    "can edit" : "poate edita",
-    "Unshare with {displayName}" : "Retrage cu {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "A apărut o eroare, nu se poate schimba retragerea calendarului.",
-    "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
     "New calendar" : "Calendar nou",
     "Name for new calendar" : "Numele noului calendar",
     "Creating calendar …" : "Se creează un calendar nou ...",
@@ -98,6 +54,13 @@ OC.L10N.register(
     "Creating subscription …" : "Se creează abonamentul ...",
     "An error occurred, unable to create the calendar." : "A apărut o eroare, nu se poate creea acest calendar.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vă rugăm să introduceți un link valid (ce începe cu ttp://, https://, webcal://, sau webcals://)",
+    "Copy subscription link" : "Copiază linkul abonamentului",
+    "Copying link …" : "Copiază link ...",
+    "Copied link" : "Link copiat",
+    "Could not copy link" : "Nu s-a putut copia link-ul",
+    "Export" : "Exportă",
+    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
+    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
     "Trash bin" : "Coș de gunoi",
     "Name" : "Nume",
     "Deleted" : "Șters",
@@ -109,6 +72,30 @@ OC.L10N.register(
     "Could not restore calendar or event" : "Nu s-a putut restaura calendarul sau evenimentul",
     "Do you really want to empty the trash bin?" : "Doriti sigur sa goliți conținutul coșului de gunoi ?",
     "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
+    "Share link" : "Partajază legătură",
+    "Copy public link" : "Copiză link-ul public",
+    "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
+    "Enter one address" : "Introdu o adresă",
+    "Sending email …" : "Email-ul se trimite ...",
+    "Copy embedding code" : "Copiați codul de încorporare",
+    "Copying code …" : "Se copiază codul ...",
+    "Copied code" : "Codul a fost copiat",
+    "Could not copy code" : "Nu sa putut copia codul",
+    "Delete share link" : "Șterge linkul partajat",
+    "Deleting share link …" : "Se şterge linkul de partajare ...",
+    "An error occurred, unable to publish calendar." : "A apărut o eroare, nu se poate publica calendarul.",
+    "An error occurred, unable to send email." : "A apărut o eroare, nu se poate trimite email-ul.",
+    "Embed code copied to clipboard." : "Codul a fost copiat în clipboard.",
+    "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
+    "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
+    "can edit" : "poate edita",
+    "Unshare with {displayName}" : "Retrage cu {displayName}",
+    "An error occurred, unable to change the unshare the calendar." : "A apărut o eroare, nu se poate schimba retragerea calendarului.",
+    "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
+    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
+    "No users or groups" : "Nu sunt utilizatori sau grupuri",
+    "Copy private link" : "Copiază link privat",
+    "Unshare from me" : "Anulare partajarea cu mine",
     "Import calendars" : "Importă calendare",
     "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
     "Filename" : "Nume fișier",
@@ -355,6 +342,7 @@ OC.L10N.register(
     "Show as" : "Arată-ne",
     "Take this event into account when calculating free-busy information." : "Ține cont de acest eveniment în momentul calculării timpului liber.",
     "Categories" : "Categorii",
+    "An error occurred, unable to delete the calendar." : "A apărut o eroare, nu se poate șterge calendarul.",
     "Commuting" : "În deplasare",
     "Talk" : "Discuție",
     "Movie" : "Film",
