@@ -8,7 +8,6 @@ OC.L10N.register(
     "Confirm" : "තහවුරු කරන්න",
     "Date:" : "දිනය:",
     "Where:" : "කොහේද:",
-    "Description:" : "විස්තරය",
     "Calendar" : "දින දර්ශනය",
     "A Calendar app for Nextcloud" : "නෙක්ස්ට් ක්ලවුඩ් සඳහා දින දර්ශන යෙදුමකි",
     "Previous day" : "පසුගිය දිනය",
@@ -26,13 +25,9 @@ OC.L10N.register(
     "Copy link" : "සබැඳිය පිටපත් කරන්න",
     "Edit" : "සංස්කරණය",
     "Untitled calendar" : "නිර්ණාමික දින දර්ශනය",
-    "Edit name" : "නම සංස්කරණය",
-    "Saving name …" : "සුරැකීමේ වර්ණය …",
-    "Edit color" : "වර්ණය සංස්කරණය",
-    "Saving color …" : "සුරැකීමේ වර්ණය …",
-    "Copy private link" : "පුද්. සබැඳිය පිටපත් කරන්න",
     "Name" : "නම",
     "Restore" : "ප්‍රතිෂ්ථාපනය",
+    "Copy private link" : "පුද්. සබැඳිය පිටපත් කරන්න",
     "Filename" : "ගොනු නාමය",
     "Cancel" : "අවලංගු කරන්න",
     "Actions" : "ක්‍රියාමාර්ග",
